@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
 ;;;  $Revision: 4532 $ | 
@@ -59,27 +59,6 @@
 ;;}}}
 ;;{{{  Advice electric insertion to talk:
 
-(defvar emacspeak-cperl-electric-insertion-commands-to-advice
-  '(cperl-electric-lbrace
-    cperl-electric-paren
-    cperl-electric-rparen
-    cperl-electric-semi
-    cperl-electric-terminator)
-  "Electric commands from CPerl to advice")
-(unless (and (boundp 'post-self-insert-hook)
-             post-self-insert-hook
-             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
-  (cl-loop for e in emacspeak-cperl-electric-insertion-commands-to-advice
-           do
-           (eval
-            `(defadvice ,e (after emacspeak pre act comp)
-               "Speak what you inserted.
-Cue electric insertion with a tone."
-               (when (ems-interactive-p)
-                 (let ((emacspeak-speak-messages nil))
-                   (emacspeak-speak-this-char last-input-event)
-                   (dtk-tone 800 100 t)))))))
-
 (defadvice cperl-electric-backspace (around emacspeak pre act)
   "Speak character you're deleting."
   (cond
