@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
 ;;;  $Revision: 4532 $ | 
@@ -126,10 +126,9 @@ Useful in voiceifying rich text."
 ;;}}}
 ;;{{{ hooks
 (add-hook 'enriched-mode-hook
-          (function
-           (lambda ()
+           #'(lambda ()
              (or emacspeak-audio-indentation
-                 (emacspeak-toggle-audio-indentation)))))
+                 (emacspeak-toggle-audio-indentation))))
 ;;}}}
 (provide  'emacspeak-enriched)
 ;;{{{  emacs local variables 
