@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
 ;;;  $Revision: 4532 $ |
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2018, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2018, T. V. Raman<tv.raman.tv@gmail.com>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -123,11 +123,9 @@ Provide an auditory icon if possible."
   :group 'eshell
   :prefix "emacspeak-eshell-")
 
-(defcustom emacspeak-eshell-ls-use-personalities t
+(defvar emacspeak-eshell-ls-use-personalities t
   "Indicates if ls in eshell uses different voice
-personalities."
-  :type 'boolean
-  :group 'emacspeak-eshell)
+personalities.")
 
 ;;}}}
 ;;{{{ voices
