@@ -5,7 +5,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
 ;;;  $Revision: 4532 $ |
@@ -290,6 +290,9 @@
 
 ;;}}}
 ;;{{{ Additional Commands:
+
+(declare-function evil-mode "evil-core" (&optional flag))
+
 ;;;###autoload
 (defun emacspeak-evil-toggle-evil ()
   "Interactively toggle evil-mode."
