@@ -5,7 +5,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
 ;;;  $Revision: 4532 $ |
@@ -137,9 +137,12 @@ Then speak the  line."
 
 ;;}}}
 ;;{{{ Fix keymap:
-(cl-declaim (special folding-mode-map))
-(when (boundp 'folding-mode-map)
-  (define-key folding-mode-map (kbd "C-e") 'emacspeak-prefix-command))
+(add-hook
+ 'folding-mode-hook
+ #'(lambda ()
+     (cl-declare (special folding-mode-map))
+     (when (boundp 'folding-mode-map)
+       (define-key folding-mode-map (ems-kbd "C-e") 'emacspeak-prefix-command))))
 
 ;;}}}
 (provide  'emacspeak-folding)
