@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
 ;;; A speech interface to Emacs |
 ;;; $Date: 2008-06-21 14:58:40 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
@@ -235,90 +235,20 @@
 
 ;;{{{  advice all navigation
 
-(defvar emacspeak-gomoku-navigation-commands
-  (list 'gomoku-beginning-of-line
-        'gomoku-end-of-line
-        'gomoku-move-down
-        'gomoku-move-up
-        'gomoku-move-left
-        'gomoku-move-right 
-        'gomoku-move-ne
-        'gomoku-move-nw
-        'gomoku-move-se
-        'gomoku-move-sw)
-  "Commands in gomoku that navigate the board")
-;;; generated by:
-                                        ;(cl-loop for command in
-                                        ;      emacspeak-gomoku-navigation-commands
-                                        ;      do
-                                        ;      (insert
-                                        ;       (format
-                                        ;        "(defadvice %s  (after emacspeak pre act comp)
-                                        ;              \"Provide auditory feedback\"
-                                        ;              (when (ems-interactive-p)
-                                        ;                (emacspeak-auditory-icon 'select-object)
-                                        ;                (emacspeak-gomoku-speak-square)))\n\n"
-                                        ;        command)))
 
-(defadvice gomoku-beginning-of-line  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
 
-(defadvice gomoku-end-of-line  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-down  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-up  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-left  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-right  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-ne  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-nw  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-se  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
-
-(defadvice gomoku-move-sw  (after emacspeak pre act comp)
-  "Provide auditory feedback"
-  (when (ems-interactive-p)
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-gomoku-speak-square)))
+(cl-loop
+ for f in
+ '(gomoku-beginning-of-line gomoku-end-of-line
+                            gomoku-move-down gomoku-move-up gomoku-move-left gomoku-move-right 
+                            gomoku-move-ne gomoku-move-nw gomoku-move-se gomoku-move-sw)
+ do
+ (eval
+  `(defadvice ,f  (after emacspeak pre act comp)
+     "Provide auditory feedback"
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'select-object)
+       (emacspeak-gomoku-speak-square)))))
 
 ;;}}}
 
