@@ -5,7 +5,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
 ;;;  $Revision: 4532 $ |
@@ -93,32 +93,26 @@
 (require 'emacspeak-preamble)
 (require 'cl-lib)
 (require 'comint)
-(require 'derived)
+(eval-when-compile (require 'derived))
 (require 'nvm "nvm" 'no-error)
 
 ;;}}}
 ;;{{{ Customizations And Variables:
 
-(defgroup emacspeak-maths nil
-  "Customize Emacspeak  Maths."
-  :group 'emacspeak)
-
-(defcustom emacspeak-maths-inferior-program
+(defvar emacspeak-maths-inferior-program
   (cond
    ((and (locate-library "nvm")
          (nvm--installed-versions))
     (let ((v (car (sort (mapcar #'car (nvm--installed-versions)) #'string>))))
       (nvm-use v)
       (executable-find "node")))
-   ;;; The fallback below  --- /usr/bin/node e.g. on Ubuntu/Debian  is old.
+;;; The fallback below  --- /usr/bin/node e.g. on Ubuntu/Debian  is old.
    ((executable-find "node") (executable-find "node")) 
    (t  nil))
   "Location of `node' executable.  Make sure the environment in which
 Emacs is launched finds the right installation of node.  M-x
 package-install nvm makes it easier to have Emacs find the right node
-install."
-  :type 'file
-  :group 'emacspeak-maths)
+install.")
 
 (cl-defstruct emacspeak-maths
   server-buffer ; comint buffer
