@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
 ;;; A speech interface to Emacs |
 ;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
@@ -67,6 +67,23 @@
   (emacspeak-auditory-icon 'select-object)
   (emacspeak-speak-line))
 ;;}}}
+;;{{{Smarter Spool-Size:
+;;; Smarter sppol-size compute functions.
+;;; These show the number of messages in a spool.
+
+(defun mspools-compute-size (file)
+  (let ((message-log-max nil)
+        (inhibit-message t)
+        (emacspeak-speak-messages nil)))
+  (read (shell-command-to-string (format "grep '^From ' %s | wc -l" file))))
+
+(defun mspools-size-folder (spool)
+  "Return (SPOOL . SIZE ) iff SIZE of spool file is non-zero."
+  (cl-declare (special mspools-folder-directory))
+  (let ((size (mspools-compute-size (expand-file-name  spool mspools-folder-directory))))
+    (unless (zerop size) (cons spool size))))
+
+;;}}}
 ;;{{{ keymaps
 (cl-declaim (special mspools-mode-map))
 (cl-eval-when (load)
