@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4448 $ |
@@ -100,7 +100,8 @@ OCR engine for optical character recognition."
   :type 'string
   :group 'emacspeak-ocr)
 
-(defcustom emacspeak-ocr-engine "ocr"
+(defcustom emacspeak-ocr-engine
+  (expand-file-name "tesseract.pl" emacspeak-etc-directory)
   "OCR engine to process acquired image."
   :type 'string
   :group 'emacspeak-ocr)
@@ -113,7 +114,7 @@ OCR engine for optical character recognition."
 
 (defcustom emacspeak-ocr-working-directory
   (expand-file-name "ocr/"
-                    emacspeak-resource-directory)
+                    emacspeak-user-directory)
   "Directory where images and OCR results
 will be placed."
   :group 'emacspeak-ocr
@@ -347,8 +348,7 @@ For detailed help, invoke command emacspeak-ocr bound to
                        emacspeak-ocr-document-name
                        buffer-read-only))
   (let  ((buffer (emacspeak-ocr-get-buffer)))
-    (save-excursion
-      (set-buffer buffer)
+    (with-current-buffer buffer
       (emacspeak-ocr-mode)
       (when (file-exists-p emacspeak-ocr-working-directory)
         (cd emacspeak-ocr-working-directory))
@@ -364,7 +364,7 @@ This name will be used as the prefix for naming image and
 text files produced in this scan.")
 
 (make-variable-buffer-local 'emacspeak-ocr-document-name)
-;;;###autoload
+
 (defun emacspeak-ocr-name-document (name)
   "Name document being scanned in the current OCR buffer.
 Pick a short but meaningful name."
@@ -380,7 +380,7 @@ Pick a short but meaningful name."
   (emacspeak-ocr-update-mode-line)
   (emacspeak-auditory-icon 'select-object)
   (emacspeak-speak-mode-line))
-;;;###autoload
+
 (defun emacspeak-ocr-scan-image ()
   "Acquire page image."
   (interactive)
@@ -420,7 +420,7 @@ Pick a short but meaningful name."
       (message "Acquired  image to file %s"
                image-name))))
 
-;;;###autoload
+
 (defun emacspeak-ocr-scan-photo (&optional metadata)
   "Scan in a photograph.
 The scanned image is converted to JPEG."
@@ -467,7 +467,7 @@ The scanned image is converted to JPEG."
 
 (defvar emacspeak-ocr-process nil
   "Handle to OCR process.")
-;;;###autoload
+
 (defun emacspeak-ocr-write-document ()
   "Writes out recognized text from all pages in current document."
   (interactive)
@@ -479,7 +479,7 @@ The scanned image is converted to JPEG."
        (point-max)
        (emacspeak-ocr-get-text-name))
       (emacspeak-auditory-icon 'save-object))))
-;;;###autoload
+
 (defun emacspeak-ocr-save-current-page ()
   "Writes out recognized text from current page
 to an appropriately named file."
@@ -513,7 +513,7 @@ to an appropriately named file."
   (emacspeak-ocr-save-current-page)
   (emacspeak-ocr-update-mode-line)
   (emacspeak-speak-line))
-;;;###autoload
+
 (defun emacspeak-ocr-recognize-image ()
   "Run OCR engine on current image.
 Prompts for image file if file corresponding to the expected
@@ -600,7 +600,7 @@ Prompts for image file if file corresponding to the expected
                           'emacspeak-ocr-process-sentinel)
     (message "Launched OCR engine.")))
 
-;;;###autoload
+
 (defun emacspeak-ocr-scan-and-recognize ()
   "Scan in a page and run OCR engine on it.
 Use this command once you've verified that the separate
@@ -610,7 +610,7 @@ correctly by themselves."
   (emacspeak-ocr-scan-image)
   (emacspeak-ocr-recognize-image))
 
-;;;###autoload
+
 (defun emacspeak-ocr-open-working-directory ()
   "Launch dired on OCR working directory."
   (interactive)
@@ -619,7 +619,7 @@ correctly by themselves."
    (dired-noselect emacspeak-ocr-working-directory))
   (emacspeak-auditory-icon 'open-object)
   (emacspeak-speak-mode-line))
-;;;###autoload
+
 (defun emacspeak-ocr-forward-page (&optional _count-ignored)
   "Like forward page, but tracks page number of current document."
   (interactive "p")
@@ -642,7 +642,7 @@ correctly by themselves."
       (emacspeak-ocr-update-mode-line)
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'large-movement))))
-;;;###autoload
+
 (defun emacspeak-ocr-backward-page (&optional _count-ignored)
   "Like backward page, but tracks page number of current document."
   (interactive "p")
@@ -675,7 +675,7 @@ correctly by themselves."
   (emacspeak-auditory-icon 'large-movement)
   (emacspeak-speak-line)
   )
-;;;###autoload
+
 (defun emacspeak-ocr-page ()
   "Move to specified page."
   (interactive)
@@ -695,7 +695,7 @@ correctly by themselves."
       (message "Not that many pages in document."))
      (t 
       (emacspeak-ocr-goto-page page)))))
-;;;###autoload
+
 (defun emacspeak-ocr-read-current-page ()
   "Speaks current page."
   (interactive)
@@ -715,7 +715,7 @@ correctly by themselves."
        (aref emacspeak-ocr-page-positions
              (1+ emacspeak-ocr-current-page-number))))))
 
-;;;###autoload
+
 (defun emacspeak-ocr-set-scan-image-options  (setting)
   "Interactively update scan image options.
 Prompts with current setting in the minibuffer.
@@ -728,7 +728,7 @@ Setting persists for current Emacs session."
   (cl-declare (special emacspeak-ocr-scan-image-options))
   (setq emacspeak-ocr-scan-image-options setting))
 
-;;;###autoload
+
 (defun emacspeak-ocr-set-compress-image-options  (setting)
   "Interactively update  image compression options.
 Prompts with current setting in the minibuffer.
