@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
 ;;;  $Revision: 4532 $ | 
@@ -143,7 +143,7 @@
 ;;{{{ advice commands
 
 (defvar emacspeak-solitaire-autoshow nil
-  "*T means rows and columns are toned as we move")
+"T means rows and columns are toned as we move")
 
 (defadvice solitaire-left (after emacspeak pre act comp)
   "Provide auditory feedback"
