@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
 ;;;  $Revision: 4670 $ |
@@ -65,25 +65,21 @@
 ;;; Code:
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-(require 'custom)
-(eval-when-compile (require 'dtk-speak))
-
 ;;}}}
 ;;{{{  state of auditory icons
 
 (defvar emacspeak-use-auditory-icons t
-  "Tells if emacspeak should use auditory icons.
-Do not set this variable by hand,
-use `emacspeak-toggle-auditory-icons' bound to
+  "Control auditory icons.
+Use `emacspeak-toggle-auditory-icons' bound to
 \\[emacspeak-toggle-auditory-icons].")
 
 (make-variable-buffer-local 'emacspeak-use-auditory-icons)
 
 ;;}}}
 ;;{{{ Setup Audio 
-;;;###autoload
+
 (defun emacspeak-audio-setup (&optional prefix)
-  "Call appropriate audio environment set command."
+  "Call amixer  command."
   (interactive "P")
   (cond
    ((executable-find "amixer")
@@ -98,41 +94,33 @@ use `emacspeak-toggle-auditory-icons' bound to
   (expand-file-name
    "classic/button.wav"
    emacspeak-sounds-directory)
-  "Default sound to play if requested icon not found.")
+  "Fallback icon.")
 
 (defvar emacspeak-sounds-themes-table
   (make-hash-table)
   "Maps valid sound themes to the file name extension used by that theme.")
 
 ;;;###autoload
-(defun emacspeak-sounds-define-theme (theme-name file-ext)
+(defsubst emacspeak-sounds-define-theme (theme-name file-ext)
   "Define a sounds theme for auditory icons. "
   (cl-declare (special emacspeak-sounds-themes-table))
   (setq theme-name (intern theme-name))
   (setf (gethash  theme-name emacspeak-sounds-themes-table)
         file-ext))
 
-(defgroup emacspeak-sounds nil
-  "Emacspeak auditory icons."
-  :group 'emacspeak)
-
 (defcustom emacspeak-sounds-default-theme
   (expand-file-name "pan-chimes/" emacspeak-sounds-directory)
   "Default theme for auditory icons. "
   :type '(directory :tag "Sound Theme Directory")
-  :group 'emacspeak-sounds)
+  :group 'emacspeak)
 
 (defcustom emacspeak-play-program
-  (cond
-   ((getenv "EMACSPEAK_PLAY_PROGRAM")
-    (getenv "EMACSPEAK_PLAY_PROGRAM"))
-   ((file-exists-p "/usr/bin/aplay") "/usr/bin/aplay")
-   ((file-exists-p "/usr/bin/play") "/usr/bin/play")
-   ((file-exists-p "/usr/bin/audioplay") "/usr/bin/audioplay")
-   ((file-exists-p "/usr/demo/SOUND/play") "/usr/demo/SOUND/play")
-   (t (expand-file-name emacspeak-etc-directory "play")))
-  "Name of executable that plays sound files. "
-  :group 'emacspeak-sounds
+  (or
+   (getenv "EMACSPEAK_PLAY_PROGRAM")
+   (executable-find "aplay")
+   (executable-find "play"))
+  "Executable that plays sound files. "
+  :group 'emacspeak
   :type 'string)
 
 (defvar emacspeak-sounds-current-theme
@@ -150,20 +138,18 @@ Do not set this by hand;
 
 (defun emacspeak-sounds-define-theme-if-necessary (theme-name)
   "Define selected theme if necessary."
-  (let ((file-name-handler-alist nil)
-        (load-source-file-function  nil))
     (cond
      ((emacspeak-sounds-theme-get-extension theme-name) t)
      ((file-exists-p (expand-file-name "define-theme.el" theme-name))
-      (load-file (expand-file-name "define-theme.el" theme-name)))
-     (t (error "Theme %s is missing its configuration file. " theme-name)))))
+      (ems--fastload (expand-file-name "define-theme.el" theme-name)))
+     (t (error "Theme %s is missing its configuration file. " theme-name))))
 
 (defun emacspeak-sounds-theme-p  (theme)
   "Predicate to test if theme is available."
   (file-exists-p
    (expand-file-name theme emacspeak-sounds-directory)))
 
-;;;###autoload
+
 (defun emacspeak-sounds-select-theme  (theme)
   "Select theme for auditory icons."
   (interactive
@@ -181,7 +167,7 @@ Do not set this by hand;
   (emacspeak-auditory-icon 'select-object))
 
 (defun emacspeak-get-sound-filename (sound-name)
-  "Retrieve name of sound file that produces  auditory icon SOUND-NAME."
+  "Get name of  file that produces  auditory icon SOUND-NAME."
   (cl-declare (special emacspeak-sounds-themes-table
                        emacspeak-sounds-current-theme))
   (let ((f
@@ -199,7 +185,7 @@ Do not set this by hand;
 
 ;;}}}
 ;;{{{  queue an auditory icon
-;;;###autoload
+
 (defun emacspeak-queue-auditory-icon (sound-name)
   "Queue auditory icon SOUND-NAME."
   (cl-declare (special dtk-speaker-process))
@@ -209,12 +195,6 @@ Do not set this by hand;
 
 ;;}}}
 ;;{{{  native player (
-;;;###autoload
-(defun emacspeak-native-auditory-icon (sound-name)
-  "Play auditory icon using native Emacs player."
-  (play-sound
-   (list 'sound
-         :file (format "%s" (emacspeak-get-sound-filename sound-name)))))
 
 ;;}}}
 ;;{{{  serve an auditory icon
@@ -234,7 +214,7 @@ Do not set this by hand;
   "Set this to nil if using paplay from pulseaudio."
   :type '(choice (string :tag "Arguments" "-q")
                  (const :tag "None" nil))
-  :group 'emacspeak-sounds)
+  :group 'emacspeak)
 
 (defun emacspeak-play-auditory-icon (sound-name)
   "Produce auditory icon SOUND-NAME."
@@ -254,20 +234,6 @@ Do not set this by hand;
 (defvar emacspeak-sox (executable-find "sox")
   "Name of SoX executable.")
 
-(defcustom emacspeak-soxplay-command 
-  (when(executable-find "play")
-    (format "%s -v 1.2 %%s  earwax &" (executable-find "play")))
-  "Name of play executable from SoX"
-  :group 'emacspeak-sounds
-  :type 'string)
-(defun emacspeak-soxplay-auditory-icon (sound-name)
-  "Produce auditory icon SOUND-NAME.
-This uses SoX play and is specifically for use with headphones."
-  (cl-declare (special emacspeak-soxplay-command))
-  (let ((icon (emacspeak-get-sound-filename sound-name)))
-    (call-process shell-file-name nil nil nil shell-command-switch
-                  (format emacspeak-soxplay-command icon))))
-
 ;;}}}
 ;;{{{ Play icon list:
 
@@ -287,19 +253,16 @@ This uses SoX play and is specifically for use with headphones."
 ;;{{{  setup play function
 
 (defcustom emacspeak-auditory-icon-function 'emacspeak-serve-auditory-icon
-  "*Function that plays auditory icons.
+"Function that plays auditory icons.
 play : Launches play-program to play.
 Serve: Send a command to the speech-server to play.
 Queue : Add auditory icon to speech queue.
-soxplay: Use sox to apply effect earwax for headphones.
 Native : Use Emacs' builtin sound support.
 Use Serve when working with remote speech servers."
-  :group 'emacspeak-sounds
+  :group 'emacspeak
   :type '(choice
           (const emacspeak-play-auditory-icon)
           (const emacspeak-serve-auditory-icon)
-          (const emacspeak-play-auditory-icon)
-          (const emacspeak-soxplay-auditory-icon)
           (const emacspeak-queue-auditory-icon)))
 
 ;;;###autoload
@@ -314,7 +277,7 @@ Use Serve when working with remote speech servers."
 ;;{{{  toggle auditory icons
 
 ;;; This is the main entry point to this module:
-;;;###autoload
+
 (defun emacspeak-toggle-auditory-icons (&optional prefix)
   "Toggle use of auditory icons.
 Optional interactive PREFIX arg toggles global value."
@@ -335,73 +298,25 @@ Optional interactive PREFIX arg toggles global value."
   (when emacspeak-use-auditory-icons
     (emacspeak-auditory-icon 'on)))
 
-(defvar emacspeak-sounds-auditory-icon-players
-  '("emacspeak-serve-auditory-icon"
-    "emacspeak-play-auditory-icon"
-    "emacspeak-play-auditory-icon")
-  "Table of auditory icon players used  when selecting a player.")
-
-(defun emacspeak-select-auditory-icon-player ()
-  "Pick a player for producing auditory icons."
-  (cl-declare (special emacspeak-sounds-auditory-icon-players))
-  (read
-   (completing-read "Select auditory icon player: "
-                    emacspeak-sounds-auditory-icon-players
-                    nil nil
-                    "emacspeak-")))
-;;;###autoload
-(defun  emacspeak-set-auditory-icon-player (player)
-  "Select  player used for producing auditory icons.
-Recommended choices:
-
-emacspeak-serve-auditory-icon for  the wave device.
-emacspeak-queue-auditory-icon when using software TTS."
-  (interactive
-   (list (emacspeak-select-auditory-icon-player)))
-  (cl-declare (special emacspeak-auditory-icon-function))
-  (setq emacspeak-auditory-icon-function player)
-  (when (called-interactively-p 'interactive)
-    (emacspeak-auditory-icon 'select-object)))
-
-;;}}}
-;;{{{ reset local player
-(defun emacspeak-sounds-reset-local-player ()
-  "Ask Emacspeak to use a local audio player.
-This lets me have Emacspeak switch to using audioplay on
-solaris after I've used it for a while from a remote session
-where it would use the more primitive speech-server based
-audio player."
-  (interactive)
-  (cl-declare (special emacspeak-play-program))
-  (if (file-exists-p "/usr/demo/SOUND/play")
-      (setq
-       emacspeak-play-program "/usr/demo/SOUND/play"
-       emacspeak-play-args "-i"
-       emacspeak-auditory-icon-function
-       'emacspeak-play-auditory-icon))
-  (if (file-exists-p "/usr/bin/audioplay")
-      (setq
-       emacspeak-play-program "/usr/bin/audioplay"
-       emacspeak-play-args "-i"
-       emacspeak-auditory-icon-function 'emacspeak-play-auditory-icon)))
-
 ;;}}}
 ;;{{{  flush sound driver
 
-(defcustom emacspeak-sounds-reset-snd-module-command nil
-  "Command to reset sound module."
-  :type '(choice
-          :tag "Command to reset sound modules"
-          (const nil :tag "None")
-          (string :tag "Command "))
-  :group 'emacspeak-sounds)
-;;;###autoload
-(defun emacspeak-sounds-reset-sound  ()
-  "Reload sound drivers."
-  (interactive)
-  (cl-declare (special emacspeak-sounds-reset-snd-module-command))
-  (when emacspeak-sounds-reset-snd-module-command
-    (shell-command emacspeak-sounds-reset-snd-module-command)))
+;;}}}
+;;{{{ emacspeak-prompts:
+
+(defvar emacspeak-prompts-directory 
+  (expand-file-name "prompts" emacspeak-sounds-directory)
+  "Where pre-defined prompt files are located.")
+
+;;;###autoload 
+(defun emacspeak-prompt (name)
+  "Play  prompt for specified name."
+  (cl-declare (special emacspeak-prompts-directory emacspeak-m-player-program))
+  (let  ((file (expand-file-name (format "%s.mp3" name)
+                                 emacspeak-prompts-directory)))
+    (cl-assert (file-exists-p file) t  "File does not exist")
+    (when emacspeak-m-player-program
+      (call-process emacspeak-m-player-program nil  0 nil  file))))
 
 ;;}}}
 (provide  'emacspeak-sounds)
