@@ -3,14 +3,12 @@
 ;;; Description:  Emacspeak Table Navigation UI
 ;;; Keywords: Emacspeak, Table UI ,  Visual layout gives structure
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2008-06-26 15:46:49 -0700 (Thu, 26 Jun 2008) $ |
 ;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
-
-;;}}}
 ;;{{{  Copyright:
 
 ;;;Copyright (C) 1995 -- 2018, T. V. Raman
@@ -45,8 +43,9 @@
 ;;{{{ requires
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
+(eval-when-compile
+  (require 'derived))
 (require 'emacspeak-preamble)
-(require 'derived)
 (require 'emacspeak-table)
 
 ;;}}}
@@ -134,7 +133,7 @@ Full List Of Keybindings:
   (set (make-local-variable 'voice-lock-mode) t)
   (put-text-property (point-min) (point-max)
                      'point-entered 'emacspeak-table-point-motion-hook)
-  (not-modified)
+  (set-buffer-modified-p nil)
   (setq buffer-undo-list t)
   (setq buffer-read-only t)
   (emacspeak-auditory-icon 'select-object)
@@ -197,7 +196,7 @@ Full List Of Keybindings:
 
 (defun emacspeak-table-synchronize-display ()
   "Bring visual display in sync with internal representation"
-  (cl-declare (special emacspeak-table positions))
+  (cl-declare (special emacspeak-table ems--positions))
   (let ((row (emacspeak-table-current-row emacspeak-table))
         (column (emacspeak-table-current-column emacspeak-table))
         (width (frame-width)))
@@ -206,7 +205,7 @@ Full List Of Keybindings:
       (gethash
        (intern
         (format "element:%s:%s" row column))
-       positions)
+       ems--positions)
       (point)))
     (scroll-left (- (current-column)
                     (+ (/ width  2)
@@ -480,10 +479,10 @@ Optional prefix arg prompts for a new filter."
     (skip-chars-backward "^,\n")))
 
 ;;}}}
-
+;;;###autoload
 (defun emacspeak-table-prepare-table-buffer (table buffer)
   "Prepare tabular data."
-  (cl-declare (special emacspeak-table positions))
+  (cl-declare (special emacspeak-table ems--positions))
   (with-current-buffer buffer
     (emacspeak-table-mode)
     (let ((i 0)
@@ -496,7 +495,7 @@ Optional prefix arg prompts for a new filter."
       (setq buffer-undo-list t)
       (erase-buffer)
       (set (make-local-variable 'emacspeak-table) table)
-      (set (make-local-variable 'positions) (make-hash-table))
+      (set (make-local-variable 'ems--positions) (make-hash-table))
       (setq count (1-  (emacspeak-table-num-columns table)))
       (cl-loop
        for row across (emacspeak-table-elements table) do
@@ -505,7 +504,7 @@ Optional prefix arg prompts for a new filter."
         (puthash
          (intern (format "element:%s:%s" i j))  ; compute key
          (point) ; insertion point  is the value
-         positions)
+         ems--positions)
         (insert
          (format "%s%s"
                  (emacspeak-table-this-element table i j)
@@ -536,7 +535,7 @@ CalTrain schedules.  Execute command `describe-mode' bound to
 \\[describe-mode] in a buffer that is in emacspeak table mode to read
 the documentation on the table browser."
   (interactive "FEnter filename containing table data: ")
-  (cl-declare (special positions))
+  (cl-declare (special ems--positions))
   (let ((buffer (get-buffer-create (format  "*%s*"
                                             (file-name-nondirectory filename))))
         (data nil)
@@ -594,7 +593,7 @@ The processed  data is  presented using emacspeak table navigation. "
       (set-buffer scratch)
       (setq buffer-undo-list t)
       (erase-buffer)
-      (insert-buffer buffer-name)
+      (insert-buffer-substring buffer-name)
       (goto-char (point-min))
       (flush-lines "^ *$")
       (goto-char (point-min))
@@ -652,7 +651,7 @@ CalTrain schedules.  Execute command `describe-mode' bound to
 \\[describe-mode] in a buffer that is in emacspeak table mode to read
 the documentation on the table browser."
   (interactive "r")
-  (cl-declare (special emacspeak-table positions))
+  (cl-declare (special emacspeak-table ems--positions))
   (let ((buffer-undo-list t)
         (workspace (get-buffer-create " table workspace  "))
         (buffer (get-buffer-create
@@ -684,7 +683,7 @@ the documentation on the table browser."
       (let ((inhibit-read-only t))
         (erase-buffer)
         (set (make-local-variable 'emacspeak-table) table)
-        (set (make-local-variable 'positions) (make-hash-table))
+        (set (make-local-variable 'ems--positions) (make-hash-table))
         (setq count (1-  (emacspeak-table-num-columns table)))
         (cl-loop for row across (emacspeak-table-elements table)
                  do
@@ -693,7 +692,7 @@ the documentation on the table browser."
                           (setf
                            (gethash
                             (intern (format "element:%s:%s" i j))
-                            positions)
+                            ems--positions)
                            (point))
                           (insert
                            (format "%s%s"
@@ -754,7 +753,7 @@ browsing table elements"
 
 (make-variable-buffer-local 'emacspeak-table-speak-element)
 
-;;;###autoload
+
 (defun emacspeak-table-next-row (&optional count)
   "Move to the next row if possible"
   (interactive "p")
@@ -765,7 +764,7 @@ browsing table elements"
   (emacspeak-table-synchronize-display)
   (funcall emacspeak-table-speak-element))
 
-;;;###autoload
+
 (defun emacspeak-table-previous-row (&optional count)
   "Move to the previous row if possible"
   (interactive "p")
@@ -776,7 +775,7 @@ browsing table elements"
   (emacspeak-table-synchronize-display)
   (funcall emacspeak-table-speak-element))
 
-;;;###autoload
+
 (defun emacspeak-table-next-column (&optional count)
   "Move to the next column if possible"
   (interactive "p")
@@ -787,7 +786,7 @@ browsing table elements"
   (emacspeak-table-synchronize-display)
   (funcall emacspeak-table-speak-element))
 
-;;;###autoload
+
 (defun emacspeak-table-previous-column (&optional count)
   "Move to the previous column  if possible"
   (interactive "p")
@@ -986,12 +985,10 @@ match, makes the matching row or column current."
   (when (called-interactively-p 'interactive)
     (emacspeak-auditory-icon 'select-object)
     (message "Copied element to register %c" register)))
-
-(emacspeak-fix-interactive-command-if-necessary 'emacspeak-table-copy-current-element-to-register)
-
-;;; Implementing table editing and table clipboard.
+;;}}}
 ;;{{{ variables
 
+;;; Implementing table editing and table clipboard.
 (defvar emacspeak-table-clipboard nil
   "Variable to hold table copied to the clipboard.")
 
@@ -1104,7 +1101,7 @@ table markup.")
 
 ;;}}}
 ;;{{{ copy and paste tables
-;;;###autoload
+
 (defun emacspeak-table-copy-to-clipboard ()
   "Copy table in current buffer to the table clipboard.
 Current buffer must be in emacspeak-table mode."
@@ -1159,8 +1156,6 @@ markup to use."
                     (insert (format "%s" col-separator)))))              (insert (format "%s" row-end)))
       (insert (format "%s" table-end))))))
 
-;;}}}
-
 ;;}}}
 ;;{{{  table sorting:
 
@@ -1242,12 +1237,12 @@ future  use."
   (interactive
    (list
     (read-file-name "Load filter settings  from file: "
-                    emacspeak-resource-directory
+                    emacspeak-user-directory
                     ".table-ui-filter")))
   (condition-case nil
       (progn
         (load
-         (expand-file-name  file emacspeak-resource-directory)))
+         (expand-file-name  file emacspeak-user-directory)))
     (error (message "Error loading resources from %s "
                     file))))
 
@@ -1256,12 +1251,12 @@ future  use."
   (interactive
    (list
     (read-file-name "Save table-ui-filter settings  to file: "
-                    emacspeak-resource-directory
+                    emacspeak-user-directory
                     ".table-ui-filter")))
-  (cl-declare (special emacspeak-resource-directory))
+  (cl-declare (special emacspeak-user-directory))
   (let ((buffer (find-file-noselect
                  (expand-file-name file
-                                   emacspeak-resource-directory))))
+                                   emacspeak-user-directory))))
     (save-current-buffer
       (set-buffer buffer)
       (erase-buffer)
