@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry: 
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com 
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
 ;;;  $Revision: 4532 $ | 
@@ -69,7 +69,7 @@
     (setq emacspeak-tetris-pronunciations-defined t)
     ;;; add tiles as repeating patterns 
      (cl-pushnew (format "%c" 0) dtk-cleanup-repeats )
-    (mapcar
+    (mapc
      #'(lambda (entry)
          (emacspeak-pronounce-add-dictionary-entry 'tetris-mode
                                                    (car entry) (cdr entry)))
@@ -208,7 +208,7 @@
 ;;{{{  Advice
 
 (defvar emacspeak-tetris-tick-period 15
-  "*Set this to a convenient value so you get time to look at what is
+"Set this to a convenient value so you get time to look at what is
 going on. Reduce it as you get better.")
 
 (defun emacspeak-tetris-tick-period ()
@@ -218,7 +218,7 @@ going on. Reduce it as you get better.")
 (cl--defalias 'tetris-get-tick-period 'emacspeak-tetris-tick-period)
 
 (defvar emacspeak-tetris-width tetris-width
-  "*Set this to different values for fun")
+"Set this to different values for fun")
 
 (defadvice tetris (around emacspeak pre act comp)
   "Tetris is speech-enabled by Emacspeak.
@@ -354,7 +354,8 @@ concentration and the game is a good mental challenge. "
     (emacspeak-auditory-icon 'open-object)
     (setq tetris-width emacspeak-tetris-width)
     (setq emacspeak-tetris-blank-row (emacspeak-tetris-blank-row))
-    (goto-line tetris-height)))
+    (goto-char (point-max))
+    (beginning-of-line)))
 
 (defadvice tetris-end-game (after emacspeak pre act comp)
   "Provide auditory feedback"
@@ -465,7 +466,8 @@ concentration and the game is a good mental challenge. "
   (interactive)
   (cl-declare (special tetris-height))
   (ems-with-messages-silenced
-   (goto-line (1+ tetris-height)))
+      (goto-char (point-max))
+    (forward-line -2))
   (emacspeak-tetris-speak-row))
 
 (defvar emacspeak-tetris-blank-row
@@ -477,7 +479,7 @@ concentration and the game is a good mental challenge. "
   (interactive)
   (cl-declare (special tetris-height
                        emacspeak-tetris-blank-row))
-  (goto-line tetris-height)
+  (goto-char (point-min))
   (search-backward emacspeak-tetris-blank-row  nil t)
   (forward-line 1)
   (emacspeak-tetris-speak-row))
