@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
 ;;;  $Revision: 4074 $ |
@@ -59,8 +59,7 @@
 
 (cl-loop
  for f in
- '(windmove-left windmove-right
-                 windmove-up windmove-down)
+ '(windmove-left windmove-right windmove-up windmove-down)
  do
  (eval
   `(defadvice  ,f (after emacspeak pre act comp)
