@@ -5,7 +5,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2007-05-03 18:13:44 -0700 (Thu, 03 May 2007) $ |
 ;;;  $Revision: 4532 $ |
@@ -59,8 +59,9 @@
 
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
-(require 'subr-x)
-(require 'derived)
+(eval-when-compile
+  (require 'subr-x)
+  (require 'derived))
 ;;}}}
 ;;{{{ Structures:
 
@@ -281,7 +282,7 @@ list of parsed ladspa-plugin structures, one per label."
            ("e" ladspa-edit-control)
            )
          do
-         (define-key ladspa-mode-map (kbd (cl-first k)) (cl-second k)))
+         (define-key ladspa-mode-map (ems-kbd (cl-first k)) (cl-second k)))
 
 ;;}}}
 ;;{{{ Instantiate Ladspa Plugin:
