@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2008-07-06 10:18:30 -0700 (Sun, 06 Jul 2008) $ |
 ;;;  $Revision: 4532 $ |
@@ -52,8 +52,6 @@
 (require 'cl-lib)
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'acss-structure)
-(require 'tts)
-
 ;;}}}
 ;;{{{ Customizations:
 
@@ -406,22 +404,6 @@ and TABLE gives the values along that dimension."
 
 ;;}}}
 ;;{{{ tts-env for Mac:
-;;;###autoload
-(defun mac-make-tts-env  ()
-  "Constructs a TTS environment for Mac."
-  (cl-declare (special mac-default-speech-rate))
-  (make-tts-env
-   :name :mac :default-voice 'paul
-   :default-speech-rate mac-default-speech-rate
-   :list-voices #'mac-list-voices
-   :acss-voice-defined-p #'mac-voice-defined-p
-   :get-acss-voice-command #'mac-get-voice-command
-   :define-voice-from-acss #'mac-define-voice-from-speech-style
-   :speech-rate-base 100 :speech-rate-step 10))
-
-(tts-env-set :mac  (mac-make-tts-env))
-
-;;}}}        
 (provide 'mac-voices)
 ;;{{{  emacs local variables
 
