@@ -6,7 +6,7 @@
 ;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
+;;; emacspeak| T. V. Raman |tv.raman.tv@gmail.com
 ;;; A speech interface to Emacs |
 ;;; $Date: 2008-07-06 10:18:30 -0700 (Sun, 06 Jul 2008) $ |
 ;;;  $Revision: 4532 $ |
@@ -52,8 +52,6 @@
 (cl-declaim  (optimize  (safety 0) (speed 3)))
 (require 'acss-structure)
 (require 'dtk-unicode)
-(require 'tts)
-
 ;;}}}
 ;;{{{ Customizations:
 
@@ -85,26 +83,17 @@
   (funcall-interactively #'dtk-select-server "outloud" device)
   (dtk-initialize))
 
-(defun outloud-32()
-  "Select 32-Outloud server."
-  (interactive)
-  (dtk-select-server "32-outloud")
-  (dtk-initialize))
-
 ;;}}}
 ;;{{{  voice table
 
 (defvar outloud-default-voice-string "`v1"
-  "Default Outloud tag for  default voice --set to be a no-op.")
+  "Outloud tag for  default voice -- no-op.")
 
 (defvar outloud-voice-table (make-hash-table)
-  "Association between symbols and strings to set Outloud  voices.
-The string can set any voice parameter.")
+  "Association between symbols and strings to set Outloud  voices. ")
 
 (defun outloud-define-voice (name command-string)
-  "Define a Outloud  voice named NAME.
-This voice will be set   by sending the string
-COMMAND-STRING to the TTS engine."
+  "Map Outloud voice `name' to `command-string'. "
   (cl-declare (special outloud-voice-table))
   (puthash name command-string outloud-voice-table))
 
@@ -117,7 +106,7 @@ COMMAND-STRING to the TTS engine."
    (t (or  (gethash name outloud-voice-table)
            outloud-default-voice-string))))
 
-(defun outloud-get-voice-command (name)
+(defsubst outloud-get-voice-command (name)
   "Retrieve command string for  voice NAME."
   (cl-declare (special dtk-speech-rate))
   (concat
@@ -163,20 +152,16 @@ COMMAND-STRING to the TTS engine."
 ;;{{{  hash table for mapping families to their dimensions
 
 (defvar outloud-css-code-tables (make-hash-table)
-  "Hash table holding vectors of outloud codes.
-Keys are symbols of the form <FamilyName-Dimension>.
-Values are vectors holding the control codes for the 10 settings.")
+  "Hash table holding vectors of outloud codes. ")
 
 (defun outloud-css-set-code-table (family dimension table)
-  "Set up voice FAMILY.
-Argument DIMENSION is the dimension being set,
-and TABLE gives the values along that dimension."
+  "Set up voice FAMILY. "
   (cl-declare (special outloud-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
     (puthash key table outloud-css-code-tables)))
 
 (defun outloud-css-get-code-table (family dimension)
-  "Retrieve table of values for specified FAMILY and DIMENSION."
+  "Retrieve table of values for  FAMILY and DIMENSION."
   (cl-declare (special outloud-css-code-tables))
   (let ((key (intern (format "%s-%s" family dimension))))
     (gethash key outloud-css-code-tables)))
@@ -275,7 +260,7 @@ and TABLE gives the values along that dimension."
 ;;}}}
 
 (defun outloud-get-average-pitch-code (value family)
-  "Get  AVERAGE-PITCH for specified VALUE and  FAMILY."
+  "Get  AVERAGE-PITCH for  VALUE and  FAMILY."
   (or family (setq family 'paul))
   (if value
       (aref (outloud-css-get-code-table family 'average-pitch)
@@ -360,7 +345,7 @@ and TABLE gives the values along that dimension."
 
 ;;}}}
 (defun outloud-get-pitch-range-code (value family)
-  "Get pitch-range code for specified VALUE and FAMILY."
+  "Get pitch-range code for  VALUE and FAMILY."
   (or family (setq family 'paul))
   (if value
       (aref (outloud-css-get-code-table family 'pitch-range)
@@ -445,7 +430,7 @@ and TABLE gives the values along that dimension."
 ;;{{{  punctuations
 
 (defun outloud-get-punctuations-code (_value)
-  "Return string needed to set specified punctuations mode."
+  "Return string  to set  punctuations mode."
   "")
 
 ;;}}}
@@ -453,7 +438,7 @@ and TABLE gives the values along that dimension."
 ;;{{{  outloud-define-voice-from-speech-style
 
 (defun outloud-define-voice-from-speech-style (name style)
-  "Define NAME to be a outloud voice as specified by settings in STYLE."
+  "Define NAME  as  per   STYLE."
   (let* ((family(acss-family style))
          (command
           (concat
@@ -477,7 +462,7 @@ and TABLE gives the values along that dimension."
 ;;{{{ Configurater
 ;;;###autoload
 (defun outloud-configure-tts ()
-  "Configure TTS environment to use ViaVoice  family of synthesizers."
+  "Configure TTS environment to use Outloud."
   (cl-declare (special tts-default-speech-rate tts-default-voice
                        outloud-default-speech-rate
                        dtk-speech-rate-step dtk-speech-rate-base))
@@ -498,24 +483,6 @@ and TABLE gives the values along that dimension."
   (dtk-unicode-update-untouched-charsets
    '(ascii latin-iso8859-1 latin-iso8859-15 latin-iso8859-9 eight-bit-graphic)))
 
-;;}}}
-;;{{{  tts-env for Outloud:
-
-;;;###autoload
-(defun outloud-make-tts-env  ()
-  "Constructs a TTS environment for Outloud."
-  (cl-declare (special outloud-default-speech-rate))
-  (make-tts-env
-   :name :outloud :default-voice 'paul
-   :default-speech-rate outloud-default-speech-rate
-   :list-voices #'outloud-list-voices
-   :acss-voice-defined-p #'outloud-voice-defined-p
-   :get-acss-voice-command #'outloud-get-voice-command
-   :define-voice-from-acss #'outloud-define-voice-from-speech-style
-   :speech-rate-base 50 :speech-rate-step 10))
-
-(tts-env-set :outloud  (outloud-make-tts-env))
-
 ;;}}}
 (provide 'outloud-voices)
 ;;{{{  emacs local variables
